@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 
 from dataclasses_json import dataclass_json
-from telescope_sdk.common import TelescopeBaseType
+from telescope_sdk.common import UserFacingDataType
 
 
 class CampaignStatus:
@@ -12,9 +12,8 @@ class CampaignStatus:
 
 @dataclass_json
 @dataclass
-class Campaign(TelescopeBaseType):
+class Campaign(UserFacingDataType):
     name: str
-    owner: str
     status: CampaignStatus
     campaign_sequence_id: str
     replenish: bool
