@@ -4,7 +4,7 @@ from typing import Optional
 
 from dataclasses_json import dataclass_json
 
-from telescope_sdk.common import TelescopeBaseType
+from telescope_sdk.common import UserFacingDataType
 
 
 class SequenceStepType(Enum):
@@ -24,5 +24,5 @@ class SequenceStep:
 
 @dataclass_json
 @dataclass
-class Sequence(TelescopeBaseType):
+class Sequence(UserFacingDataType):
     steps: list[SequenceStep]
